@@ -68,7 +68,8 @@ class Parameter():
                             str_data = f'参数 {_k} 应该符合 {verify[_k]} 格式'
                     else:
                         str_data = f'参数 {_k} 应该是 {verify[_k]} 类型'
-                if not null_value and verify[_k] == str and not optional.__contains__(_k):
+                if not null_value and verify[_k] == str and not optional.__contains__(_k) and not str_data:
+                    # 字符串不允许为空 AND 要求为字符串 AND 不是可选参数 AND 前面没有其他错误
                     if not _v.strip():
                         str_data = f'参数 {_k} 不能是空字符串'
                 if str_data:
